1. Go to mapshaper.org
2. Load your region's `GeoJSON`. In this example, we use the `GeoJSON` of Uttar Pradesh.
3. Activate information view (right-side, `i` icon). Click a region to view its attributes (Id, State, Statename, DT_CODE etc.)
4. Activate console view (top right, `Console` option). Console option lets you control the layer with all options.
5. Filter only the necessary attributes using a command. Here we are interested in a small subset of fields: `Id, State, Statename, DT_CODE, DT_Name, CD_Block, BLOCK_NAME`.
6. Export the filtered file (top right, `Export` option) in a suitable format.

Notice that only the attributes ones we filtered are retained in the output file.